OC.L10N.register(
    "settings",
    {
    "Private" : "Súkromný",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Viditeľné iba pre ľudí s integráciou telefónneho čísla prostredníctvom aplikácie Talk pre mobil",
    "Local" : "Lokálny",
    "Only visible to people on this instance and guests" : "Viditeľné iba pre ľudí na tejto inštancii a hostí",
    "Federated" : "Federovaný",
    "Only synchronize to trusted servers" : "Synchronizovať iba s dôveryhodnými servermi",
    "Published" : "Publikované",
    "Synchronize to trusted servers and the global and public address book" : "Synchronizovať s dôveryhodnými servermi a globálnym a verejným adresárom",
    "Verify" : "Overiť",
    "Verifying …" : "Overovanie ...",
    "Unable to change password" : "Zmena hesla sa nepodarila",
    "Very weak password" : "Veľmi slabé heslo",
    "Weak password" : "Slabé heslo",
    "So-so password" : "Priemerné heslo",
    "Good password" : "Dobré heslo",
    "Strong password" : "Silné heslo",
    "Groups" : "Skupiny",
    "Group list is empty" : "Zoznam skupín je prázdny",
    "Unable to retrieve the group list" : "Nie je možné načítať zoznam skupín",
    "{actor} added you to group {group}" : "používateľ {actor} vás pridal do skupiny {group}",
    "You added {user} to group {group}" : "Pridali ste používateľa {actor} do skupiny {group}",
    "{actor} added {user} to group {group}" : "{actor} pridal(a) používateľa {user} do skupiny {group}",
    "An administrator added you to group {group}" : "Správca vás pridal do skupiny {group}",
    "An administrator added {user} to group {group}" : "Správca pridal používateľa {user} do skupiny {group}",
    "{actor} removed you from group {group}" : "{actor} vás odobral(a) zo skupiny {group}",
    "You removed {user} from group {group}" : "Odobrali ste používateľa {user} zo skupiny {group}",
    "{actor} removed {user} from group {group}" : "{actor} odobral(a) používateľa {user} ze skupiny {group}",
    "An administrator removed you from group {group}" : "Správca vás odobral ze skupiny {group}",
    "An administrator removed {user} from group {group}" : "Správca odobral používateľa {user} zo skupiny {group}",
    "Your <strong>group memberships</strong> were modified" : "Bolo upravené vaše <strong>členstvo v skupinách</strong>",
    "{actor} changed your password" : "{actor} zmenil Vaše heslo",
    "You changed your password" : "Zmenili ste si heslo",
    "Your password was reset by an administrator" : "Vaše heslo bolo resetované administrátorom",
    "Your password was reset" : "Vaše heslo bolo znova nastavené",
    "{actor} changed your email address" : "{actor} zmenil Vašu emailovú adresu",
    "You changed your email address" : "Zmenili ste si emailovú adresu",
    "Your email address was changed by an administrator" : "Vaša emailová adresa bola zmenená administrátorom",
    "You deleted app password \"{token}\"" : "Vymazali ste heslo pre aplikáciu \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Premenovali ste heslo aplikácie \"{token}\" na \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Povolili ste prístup k súborovému systému aplikácii, používajúcej heslo \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Zrušili ste prístup k súborovému systému pre aplikáciu, používajúcej heslo \"{token}\"",
    "Security" : "Zabezpečenie",
    "You successfully logged in using two-factor authentication (%1$s)" : "Úspešne ste sa prihlásili pomocou dvoj-faktorovej autentizácie (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Pokus o prihlásenie s použitím dvoj-faktorovej autentizácie zlyhal (%1$s)",
    "Remote wipe was started on %1$s" : "Vymazanie na diaľku sa začalo na %1$s",
    "Remote wipe has finished on %1$s" : "Vymazanie na diaľku sa skončilo na %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Vaše <strong>heslo</strong> alebo <strong>email</strong> bolo zmenené",
    "Apps" : "Apky",
    "Could not remove app." : "Aplikáciu nie je možné zmazať.",
    "Could not update app." : "Nepodarilo sa aktualizovať aplikáciu.",
    "Wrong password" : "Nesprávne heslo",
    "Unable to change personal password" : "Nepodarilo sa zmeniť osobné heslo",
    "Saved" : "Uložené",
    "No user supplied" : "Nebol uvedený používateľ",
    "Unable to change password. Password too long." : "Nepodarilo sa zmeniť heslo. Heslo je veľmi dlhé.",
    "Authentication error" : "Chyba autentifikácie",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Zadajte administrátorské heslo pre obnovu, inak budú všetky používateľské dáta stratené.",
    "Wrong admin recovery password. Please check the password and try again." : "Chybné administrátorské heslo pre obnovu. Skontrolujte správnosť hesla a skúste to znovu.",
    "Backend does not support password change, but the user's encryption key was updated." : "Backend nepodporuje zmenu hesla, ale šifrovací kľúč používateľa bol zmenený.",
    "installing and updating apps via the App Store or Federated Cloud Sharing" : "Inštalovať a aktualizovať aplikácie pomocou obchodu alebo Vzdialeného Cloudového Úložiska",
    "Federated Cloud Sharing" : "Sprístupnenie prostredníctvom Federated Cloud",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL používa zastaralú %1$s verziu (%2$s). Prosím aktualizujte si operačný systém pretože %3$s nebude fungovať spoľahlivo.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "Nepodarilo sa zistiť, či je verzia TLS knižnice cURL zastaraná alebo nie, pretože sa vyskytla chyba počas požiadavky HTTPS na https://nextcloud.com. Ďalšie podrobnosti nájdete v log súbore nextcloud.",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "Modul OPcache PHP nie je načítaný. Pre lepší výkon sa odporúča načítať ho do vašej inštalácie PHP.",
    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcache je vypnutá. Pre lepší výkon sa odporúča vložiť do konfigurácie PHP <code>opcache.enable=1</code>.",
    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache je nakonfigurovaná na odstraňovanie komentárov kódu. Ak je povolená OPcache, musí byť nastavený <code>opcache.save_comments=1</code>, aby Nextcloud fungoval.",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud nemá povolené používať OPcache API. Keď je OPcache povolená, dôrazne sa odporúča zahrnúť všetky adresáre Nextcloud s <code>opcache.restrict_api</code> alebo zrušiť toto nastavenie, aby ste deaktivovali obmedzenia API OPcache a aby ste predišli chybám počas aktualizácie jadra alebo aplikácie Nextcloud.",
    "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud nemá povolené používať OPcache API. Keď je OPcache povolená, dôrazne sa odporúča zahrnúť všetky adresáre Nextcloud s <code>opcache.restrict_api</code> alebo zrušiť toto nastavenie, aby ste deaktivovali obmedzenia API OPcache a aby ste predišli chybám počas aktualizácie jadra alebo aplikácií Nextcloud.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Maximálny počet kľúčov OPcache je takmer prekročený. Aby ste sa uistili, že všetky skripty môžu byť uložené vo vyrovnávacej pamäti, odporúča sa použiť <code>opcache.max_accelerated_files</code> na vašu konfiguráciu PHP s hodnotou vyššou ako <code>%s</code>.",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "Vyrovnávacia pamäť OPcache je takmer plná. Aby ste sa uistili, že všetky skripty môžu byť uložené vo vyrovnávacej pamäti, odporúča sa použiť <code>opcache.max_accelerated_files</code> na vašu konfiguráciu PHP s hodnotou vyššou ako <code>%s</code>.",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "Vyrovnávacia pamäť interných reťazcov OPcache je takmer plná. Aby ste sa uistili, že opakujúce sa reťazce možno efektívne ukladať do vyrovnávacej pamäte, odporúča sa použiť na konfiguráciu PHP <code>opcache.interned_strings_buffer</code> s hodnotou vyššou ako <code>%s</code>.",
    "Administrator documentation" : "Príručka administrátora",
    "User documentation" : "Príručka používateľa",
    "Invalid SMTP password." : "Nesprávne heslo pre SMTP.",
    "Email setting test" : "Test nastavení emailu",
    "Well done, %s!" : "Dobrá práca, %s!",
    "If you received this email, the email configuration seems to be correct." : "Ak ste prijali tento email, emailová konfigurácia sa zdá byť správna.",
    "Email could not be sent. Check your mail server log" : "Nepodarilo sa odoslať email. Skontrolujte log Vášho mail servera",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Vyskytol sa problém pri odosielaní emailu. Prosím, znovu skontrolujte svoje nastavenia. (Chyba: %s)",
    "You need to set your user email before being able to send test emails. Go to %s for that." : "Musíte nastaviť svoj ​​užívateľský email, než budete môcť odoslať testovací email. Aby ste tak urobili choďte na %s.",
    "Users" : "Užívatelia",
    "Invalid user" : "Neplatný užívateľ",
    "Invalid mail address" : "Neplatná emailová adresa",
    "Settings saved" : "Nastavenia uložené",
    "Unable to change full name" : "Nemožno zmeniť meno a priezvisko",
    "Unable to change email address" : "Nemožno zmeniť emailovú adresu",
    "Unable to set invalid phone number" : "Nie je možné nastaviť neplatné telefónne číslo",
    "Unable to set invalid website" : "Nie je možné nastaviť neplatnú webstránku",
    "Some account data was invalid" : "Niektoré dáta účtu boli neplatné",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Ak chcete overiť svoj Twitter účet, napíšte nasledujúci tweet (uistite sa, že ho zasielate bez zalomenia riadkov):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Pre verifikáciu vašich webových stránok uložte nasledujúci obsah v koreňovom adresári webovej stránky v umiestnení '.well-known/CloudIdVerificationCode.txt' (uistite sa, že bol text vložený ako jediný riadok)",
    "%1$s changed your password on %2$s." : "%1$s zmenil Vaše heslo na %2$s.",
    "Your password on %s was changed." : "Vaše heslo na %s bolo zmenené.",
    "Your password on %s was reset by an administrator." : "Vaše heslo na %s bolo resetované administrátorom.",
    "Your password on %s was reset." : "Vaše heslo na %s bolo znova nastavené.",
    "Password for %1$s changed on %2$s" : "Heslo pre %1$s bolo zmenené na %2$s",
    "Password changed for %s" : "Heslo zmenené pre %s",
    "If you did not request this, please contact an administrator." : "Ak ste to nevyžadovali, prosím kontaktujte administrátora.",
    "Your email address on %s was changed." : "Vaša emailová adresa na %s bola zmenená.",
    "Your email address on %s was changed by an administrator." : "Vaša emailová adresa na %s bola zmenená administrátorom.",
    "Email address for %1$s changed on %2$s" : "Emailová adresa pre %1$s zmenená na %2$s",
    "Email address changed for %s" : "Emailová adresa zmenená pre %s",
    "The new email address is %s" : "Nová emailová adresa je %s",
    "Your %s account was created" : "Váš účet %s bol vytvorený",
    "Welcome aboard" : "Vitajte na palube",
    "Welcome aboard %s" : "Vitajte na palube %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Vitajte vo vašom %s účte, môžete pridávať, chrániť a zdieľať svoje dáta.",
    "Your username is: %s" : "Vaše používateľské meno je: %s",
    "Set your password" : "Nastavte si heslo",
    "Go to %s" : "Prejsť na %s",
    "Install Client" : "Inštalácia klienta",
    "Logged in user must be a subadmin" : "Prihlásený používateľ musí byť sub-správca",
    "Settings" : "Nastavenia",
    "Personal" : "Osobné",
    "Administration" : "Administrácia",
    "Additional settings" : "Ďalšie nastavenia",
    "Administration privileges" : "Oprávnenia správcu",
    "Groupware" : "Groupware",
    "Overview" : "Prehľad",
    "Basic settings" : "Základné nastavenia",
    "Sharing" : "Sprístupňovanie",
    "Availability" : "Dostupnosť",
    "Calendar" : "Kalendár",
    "Personal info" : "Osobné informácie",
    "Mobile & desktop" : "Mobil a počítač",
    "Email server" : "Email server",
    "Security & setup warnings" : "Bezpečnosť a nastavenia upozornení",
    "Background jobs" : "Úlohy na pozadí",
    "Create" : "Vytvárať",
    "Change" : "Zmeniť",
    "Delete" : "Zmazať",
    "Reshare" : "Zdieľať ďaľej",
    "Unlimited" : "Nelimitované",
    "Verifying" : "Overovanie",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Úloha na pozadí, čaká na kontrolu importovaných SSL certifikátov používateľov. Skúste to znova neskôr.",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Je niekoľko SSL certifikátov importovaných používateľmi, ktoré sa už v NextCloud 21 nepoužívajú. Môžu byť importované z príkazového riadku pomocou \"occ security:certificates:import\". Ich cesty vo vnútri dátového priečinka sú uvedené nižšie.",
    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "Boli nájdené neplatné UUID užívateľov alebo skupín LDAP. Skontrolujte svoje nastavenia „Prepísať detekciu UUID“ v expertnej časti konfigurácie LDAP a použite „occ ldap:update-uuid“ na ich aktualizáciu.",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Starý formát šifrovania na strane servera je povolený. Odporúčame vám to zakázať.",
    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "Používa sa verzia MariaDB \"%s\". Nextcloud 21 a vyšší už nebude podporovať túto verziu a vyžaduje MariaDB 10.2 alebo novšiu.",
    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "Používa sa verzia MySQL \"%s\". Nextcloud 21 a vyšší už nebude podporovať túto verziu a vyžaduje MySQL 8.0 alebo MariaDB 10.2 alebo novšia.",
    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "Používa sa verzia PostgreSQL \"%s\". Nextcloud 21 a vyšší už nebude podporovať túto verziu a vyžaduje PostgreSQL 9.6 alebo novší.",
    "Profile information" : "Informácie o profile",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profilový obrázok, celé meno, e-mail, telefónne číslo, adresa, webová stránka, Twitter, organizácia, rola, titulok, životopis a či je váš profil povolený",
    "Nextcloud settings" : "Nastavenia Nextcloud",
    "Here you can decide which group can access certain sections of the administration settings." : "Tu sa môžete rozhodnúť, ktorá skupina má prístup k niektorým nastaveniam správcu.",
    "None" : "Žiadny",
    "Unable to modify setting" : "Nie je možné zmeniť nastavenie",
    "Two-Factor Authentication" : "Dvojzložkové overovanie",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Dvojfázové overenie je možné vynútiť pre všetkých používateľov a konkrétne skupiny. Ak nemajú nastaveného poskytovateľa dvojfázového overovania nebudú sa môcť prihlásiť do systému.",
    "Enforce two-factor authentication" : "Vynútiť dvojzložkové overovanie",
    "Limit to groups" : "Povoľ len pre skupiny",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Vynútenie dvojzložkového overovania je možné nastaviť len pre určité skupiny.",
    "Two-factor authentication is enforced for all members of the following groups." : "Dvojfázové overovanie sa vynúti pre všetkých členov nasledujúcich skupín.",
    "Enforced groups" : "Vynútené skupiny",
    "Two-factor authentication is not enforced for members of the following groups." : "Dvojfázové overovanie sa nevynucuje pre členov nasledujúcich skupín.",
    "Excluded groups" : "Vynechané skupiny",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Pokiaľ sú skupiny vybraté/vynechané, je pre zisťovanie či je používateľovi vynútené dvojzložkové (2FA) overovanie použitá nasledovná logika: Ak nie sú vybraté žiadne skupiny, je 2FA zapnuté pre všetkých okrem členov vynechaných skupín. Ak sú nejaké skupiny vybraté, je 2FA zapnuté pre všetkých jej členov. Ak je používateľ členom ako vybratej, tak aj vynechanej skupiny, potom má vybratá skupina prednosť a 2FA je vynútené.",
    "Save changes" : "Uložiť zmeny",
    "All" : "Všetky",
    "Limit app usage to groups" : "Obmedziť používanie aplikácií pre skupiny",
    "No results" : "Žiadne výsledky",
    "Update to {version}" : "Aktualizovať na {version}",
    "Remove" : "Odstrániť",
    "Disable" : "Zakázať",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Pre túto aplikáciu nie je zadaná minimálna verzia Nextcloudu. Toto v budúcnosti spôsobí chybu.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Pre túto aplikáciu nie je zadaná maximálna verzia Nextcloudu. Toto v budúcnosti spôsobí chybu.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Túto aplikáciu nemožno nainštalovať, pretože nie sú splnené nasledovné závislosti:",
    "View in store" : "Zobraz v obchode",
    "Visit website" : "Navštíviť webstránku",
    "Report a bug" : "Nahlásiť chybu",
    "Admin documentation" : "Príručka administrátora",
    "Developer documentation" : "Dokumentácia vývojára",
    "This app is supported via your current Nextcloud subscription." : "Táto aplikácia je podporovaná prostredníctvom vášho aktuálneho predplatného Nextcloud.",
    "Supported" : "Podporované",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Odporúčané aplikácie sú vyvíjané komunitou Sú prepojené so zbytkom Nextcloud a pripravené na produkčné nasadenie.",
    "Featured" : "Doporučená",
    "Update to {update}" : "Aktualizovať na {update}",
    "All apps are up-to-date." : "Všetky aplikácie sú aktuálne.",
    "Results from other categories" : "Výsledku z ostatných kategórií",
    "No apps found for your version" : "Aplikácie pre vašu verziu sa nenašli",
    "Disable all" : "Zakázať všetko",
    "Enable all" : "Povoliť všetko",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n aplikácia má dostupnú aktualizáciu","%n aplikácie majú dostupné aktualizácie","%n aplikácie majú dostupné aktualizácie ","%n aplikácií má dostupné aktualizácie"],
    "_Update_::_Update all_" : ["Aktualizovať všetko","Aktualizovať všetko","Aktualizovať všetko","Aktualizovať všetko"],
    "Marked for remote wipe" : "Označené na vymazanie na diaľku",
    "Device settings" : "Nastavenia zariadenia",
    "Allow filesystem access" : "Povoliť prístup ku súborovému systému",
    "Rename" : "Premenovať",
    "Revoke" : "Odvolať",
    "Wipe device" : "Vymazať obsah zariadenia",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Ostránenie tohto tokenu môže zabrániť vymazaniu vášho zariadenia, ak sa ešte nezačalo mazanie.",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome pre Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "{productName} iOS app" : "{productName} iOS aplikácia",
    "{productName} Android app" : "{productName} Android aplikácia",
    "{productName} Talk for iOS" : "{productName} Talk pre iOS",
    "{productName} Talk for Android" : "{productName} Talk pre Android",
    "Sync client - {os}" : "Sync client - {os}",
    "This session" : "Táto relácia",
    "Device" : "Zariadenie",
    "Last activity" : "Posledná aktivita",
    "Devices & sessions" : "Zariadenia a relácie",
    "Web, desktop and mobile clients currently logged in to your account." : "Weboví, desktopoví, alebo mobilní klienti práve prihlásení na váš účet.",
    "Do you really want to wipe your data from this device?" : "Naozaj chcete vymazať svoje údaje z tohto zariadenia?",
    "Confirm wipe" : "Potvrďte vymazanie",
    "Error while creating device token" : "Chyba pri vytváraní tokenov zariadenia",
    "Error while updating device token scope" : "Chyba pri aktualizácii rozsahu tokenu zariadenia",
    "Error while updating device token name" : "Chyba pri aktualizácii názvu tokenu zariadenia",
    "Error while deleting the token" : "Chyba pri mazaní tokenu",
    "Error while wiping the device with the token" : "Chyba pri vymazávaní zariadenia s tokenom",
    "App name" : "Názov aplikácie",
    "Create new app password" : "Vytvoriť nové heslo aplikácie",
    "Use the credentials below to configure your app or device." : "Pre konfiguráciu vašej aplikácie, alebo zariadenia použite nižšie uvedené prihlasovacie údaje.",
    "For security reasons this password will only be shown once." : "Z dôvodu bezpečnosti toto heslo bude zobrazené iba jeden krát.",
    "Username" : "Používateľské meno",
    "Password" : "Heslo",
    "Done" : "Hotovo",
    "Show QR code for mobile apps" : "Zobraziť QR kód pre mobilné apky",
    "Copied!" : "Skopírované!",
    "Copy" : "Kopírovať",
    "Could not copy app password. Please copy it manually." : "Nie je možné skopírovať heslo pre aplikáciu. Skopírujte ho ručne.",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Pre optimálny výkon je dôležité nakonfigurovať úlohy na pozadí správne. Odporúča sa 'Cron'. Viac informácií je možné nájsť v dokumentácii.",
    "Last job execution ran {time}. Something seems wrong." : "Úloha naposledy prebehla za %s. Zdá sa, že niečo nie je v poriadku.",
    "Last job ran {relativeTime}." : "Posledná úloha bežala {relativeTime}.",
    "Background job did not run yet!" : "Úloha na pozadí ešte nebežala!",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single user instance." : "S každou načítanou stránkou spustiť jednu úlohu. Prípad použitia: Inštancia jedného používateľa.",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php je zaregistrovaný v službe webcron, aby každých 5 minút volal cron.php cez HTTP. Prípad použitia: Veľmi malá inštancia (1–5 používateľov v závislosti od použitia).",
    "Cron (Recommended)" : "Cron (Odporúčané)",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Pre spustenie potrebujete mať rozšírenie PHP POSIX. Viac detailov v {linkstart}PHP dokumentácii{linkend}.",
    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Použiť systémový plánovač (cron) pre spustenie súboru cron.php každých 5 minút. Odporúčané pre všetky inštancie.",
    "The cron.php needs to be executed by the system user \"{user}\"." : "Je potrebné, aby cron.php bol spustený systémovým používateľom \"{user}\".",
    "Unable to update background job mode" : "Nie je možné aktualizovať režim úlohy na pozadí",
    "Profile" : "Profil",
    "Enable or disable profile by default for new users." : "Predvolene povoliť alebo zakázať profil pre nových používateľov.",
    "Enable" : "Zapnúť",
    "Unable to update profile default setting" : "Nie je možné aktualizovať predvolené nastavenie profilu",
    "Server-side encryption" : "Šifrovanie na serveri",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Šifrovanie na strane servera umožňuje zašifrovať súbory, ktoré sú na tento server nahrávané. To prináša obmedzenia ako napr. výkonnostné obmedzenie, takže to povoľte len ak je to naozaj potrebné.",
    "Enable server-side encryption" : "Povoliť šifrovanie na serveri",
    "Please read carefully before activating server-side encryption:" : "Prečítajte prosím pozorne pred použitím šifrovania na strane servera:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Potom ako sa zapne šifrovanie sú od toho bodu všetky nahrávané súbory šifrované serverom. Vypnutie šifrovania bude možné až vtedy, keď bude šifrovací modul túto možnosť podporovať a po splnení všetkých nutných podmenok (tzn. nastavenie kľúčov pre obnovenie).",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Samotné šifrovanie negarantuje bezpečnosť systému. Ak sa chcete dozvedieť viac o tom ako funguje aplikácia pre šifrovanie a aké sú podporované prípady použitia, prečítajte si prosím dokumentáciu.",
    "Be aware that encryption always increases the file size." : "Majte na vedomí, že šifrovanie vždy zväčší veľkosť súborov.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Je dobré vytvárať pravidelné zálohy vašich dát, uistite sa, že v prípade šifrovania spolu s vašimi dátami zálohujete aj šifrovacie kľúče.",
    "This is the final warning: Do you really want to enable encryption?" : "Toto je posledné varovanie: Vážne si prajete povoliť šifrovanie?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Nebol načítaný žiadny šifrovací modul, povoľte prosím šifrovací modul v menu aplikácií.",
    "Select default encryption module:" : "Vybrať predvolený šifrovací modul:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Musíte zmigrovať svoje šifrovacie kľúče zo starého šifrovania (ownCloud <= 8.0) na nové. Povoľte „Predvolený modul šifrovania“ a spustite príkaz {command}",
    "Unable to update server side encryption config" : "Nedá sa aktualizovať konfigurácia šifrovania na strane servera",
    "Rename group" : "Premenovať skupinu",
    "Remove group" : "Odstrániť skupinu",
    "You are about to remove the group {group}. The users will NOT be deleted." : "Chystáte sa odstrániť skupinu {group}.  Používatelia NEBUDÚ vymazaní.",
    "Please confirm the group removal " : "Prosím potvrďte vymazanie skupiny.",
    "Current password" : "Aktuálne heslo",
    "New password" : "Nové heslo",
    "Change password" : "Zmeniť heslo",
    "Your profile picture" : "Váš profilový obrázok",
    "Upload profile picture" : "Nahrať profilový obrázok",
    "Remove profile picture" : "Odstrániť profilový obrázok",
    "Picture provided by original account" : "Obrázok poskytnutý originálnym účtom",
    "Cancel" : "Zrušiť",
    "Set as profile picture" : "Nastaviť ako profilový obrázok",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Upozorňujeme, že aktualizácia vášho profilového obrázka môže trvať až 24 hodín.",
    "Choose your profile picture" : "Vyberte si váš profilový obrázok",
    "Please select a valid png or jpg file" : "Prosím vyberte platný png alebo jpg súbor",
    "Error setting profile picture" : "Chyba pri nastavovaní profilového obrázku",
    "Error cropping profile picture" : "Chyba pri orezávaní profilového obrázku",
    "Error saving profile picture" : "Chyba pri ukladaní profilového obrázku",
    "Error removing profile picture" : "Chyba pri odstraňovaní profilového obrázku",
    "Your biography" : "Váš životopis",
    "Details" : "Detaily",
    "You are a member of the following groups:" : "Ste členom nasledovných skupín:",
    "You are using <strong>{usage}</strong>" : "Využívate <strong>{usage}</strong>",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Využívate <strong>{usage}</strong> z <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
    "Your full name" : "Vaše celé meno",
    "Email options" : "Možnosti E-mailu",
    "Primary email for password reset and notifications" : "Primárny e-mail na obnovenie hesla a zasielanie upozornení",
    "Remove primary email" : "Odobrať primárny email",
    "Delete email" : "Zmazať email",
    "Unset as primary email" : "Zrušiť nastavenie ako primárny e-mail",
    "This address is not confirmed" : "Táto adresa nie je potvrdená",
    "Set as primary email" : "Nastaviť ako primárny e-mail",
    "Your email address" : "Vaša emailová adresa",
    "Additional email address {index}" : "Ďaľšia e-mail adresa {index}",
    "Unable to delete primary email address" : "Nie je možné zmazať primárnu e-mail adresu",
    "Unable to update primary email address" : "Nie je možné aktualizovať primárnu e-mail adresu",
    "Unable to add additional email address" : "Nie je možné pridať ďalšiu e-mail adresu",
    "Unable to update additional email address" : "Nie je možné aktualizovať ďalšiu e-mail adresu",
    "Unable to delete additional email address" : "Nie je možné odstrániť ďalšiu e-mail adresu",
    "No email address set" : "Emailová adresa nie je nastavená",
    "Additional emails" : "Ďalšie e-maily",
    "Your headline" : "Váš titulok",
    "Language" : "Jazyk",
    "Help translate" : "Pomôcť s prekladom",
    "Unable to update language" : "Nie je možné aktualizovať jazyk",
    "No language set" : "Nie je nastavený žiadny jazyk",
    "Locale" : "Miestne nastavenie",
    "Week starts on {firstDayOfWeek}" : "Začiatok týždňa je {firstDayOfWeek}",
    "Unable to update locale" : "Nie je možné aktualizovať miestne nastavenie",
    "No locale set" : "Nie je nastavené žiadne miestne nastavenie",
    "Your location" : "Vaša poloha",
    "Your organisation" : "Vaša organizácia",
    "Your phone number" : "Vaše telefónne číslo",
    "Edit your Profile visibility" : "Upraviť viditeľnosť vášho profilu",
    "Enable Profile" : "Povoliť Profil",
    "Unable to update profile enabled state" : "Nie je možné aktualizovať stav aktivácie profilu",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Vo vašom profile sa rešpektuje prísnejšie nastavenie viditeľnosti alebo rozsahu. Ak je napríklad viditeľnosť nastavená na „Zobraziť všetkým“ a rozsah je nastavený na „Súkromné“, „Súkromné“ bude rešpektované.",
    "Unable to update visibility of {displayId}" : "Nie je možné aktualizovať viditeľnosť {displayId}",
    "Your role" : "Vaša rola",
    "Your Twitter handle" : "Vaša stránka na Twitteri",
    "Your website" : "Vaša webstránka",
    "No {property} set" : "Nie je nastavená žiadna {property}",
    "Unable to update {property}" : "Nie je možné aktualizovať {property}",
    "Change scope level of {property}, current scope is {scope}" : "Zmeniť úroveň rozsahu {property}, aktuálny rozsah je {scope}",
    "Unable to update federation scope of the primary {property}" : "Nie je možné aktualizovať rozsah federácie primárneho {property}",
    "Unable to update federation scope of additional {property}" : "Nie je možné aktualizovať rozsah federácie ďalšieho {property}",
    "Add additional email" : "Pridať ďalší e-mail",
    "Add" : "Pridať",
    "You do not have permissions to see the details of this user" : "Nemáte oprávnenie vidieť detaily tohoto používateľa",
    "Add new password" : "Pridať nové heslo",
    "Add new email address" : "Pridať novú emailovú adresu",
    "Add user to group" : "Pridať užívateľa do skupiny",
    "Set user as admin for" : "Nastaviť používateľa ako správcu pre",
    "Select user quota" : "Zvoliť kvótu používateľa",
    "Delete user" : "Zmazať používateľa",
    "Wipe all devices" : "Vymazať zo všetkých zariadení",
    "Disable user" : "Zablokovať používateľa",
    "Enable user" : "Odblokovať používateľa",
    "Resend welcome email" : "Znova odoslať privítací email",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "V prípade straty zariadenia alebo napr. odchodu z firmy to môže na daľku vymazať údaje Nextcloud zo všetkých zariadení priradených k {userid}. Funguje iba vtedy, ak sú zariadenia pripojené k internetu.",
    "Remote wipe of devices" : "Vymazať obsah zariadení na diaľku",
    "Wipe {userid}'s devices" : "Vymazať obsah zariadení {userid}",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Úplne odstráiť účet používateľa {userid} vrátane všetkých osobných súborov, údajov aplikácií atď.",
    "Account deletion" : "Zmazanie účtu",
    "Delete {userid}'s account" : "Vymazať účet {userid}",
    "Welcome mail sent!" : "Privítací email odoslaný",
    "Edit User" : "Upraviť používateľa",
    "Toggle user actions menu" : "Prepnúť ponuku akcií používateľa",
    "{size} used" : "{size} použité",
    "New user" : "Nový používateľ",
    "Will be autogenerated" : "Bude automaticky vytvorené",
    "Display name" : "Zobrazované meno",
    "Email" : "Email",
    "Default language" : "Predvolený jazyk",
    "Add a new user" : "Pridať nového používateľa",
    "Group admin for" : "Administrátor skupiny pre",
    "Quota" : "Kvóta",
    "User backend" : "Backend používateľa",
    "Storage location" : "Umiestnenie úložiska",
    "Last login" : "Posledné prihlásenie",
    "No users in here" : "Nie sú tu žiadni používatelia",
    "Default quota" : "Predvolená kvóta",
    "Common languages" : "Spoločné jazyky",
    "Other languages" : "Iné jazyky",
    "Password change is disabled because the master key is disabled" : "Zmena hesla je zablokovaná pretože hlavný kľúč je vypnutý",
    "Passwordless authentication requires a secure connection." : "Overenie bez hesla vyžaduje zabezpečné pripojenie.",
    "Add WebAuthn device" : "Pridať zariadenie WebAuthn",
    "Please authorize your WebAuthn device." : "Autorizujte svoje zariadenie WebAuthn.",
    "Name your device" : "Pomenujte svoje zariadenie",
    "Adding your device …" : "Pridáva sa zariadenie...",
    "Server error while trying to add WebAuthn device" : "Chyba servera pri pokuse o pridanie zariadenia WebAuthn",
    "Server error while trying to complete WebAuthn device registration" : "Chyba servera pri pokuse o dokončenie registrácie zariadenia WebAuthn",
    "Unnamed device" : "Nepomenované zariadenie",
    "Passwordless Authentication" : "Overovanie bez hesla",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Nastavte si účet pre využívanie overovania bez hesla podľa štandardu FIDO2.",
    "No devices configured." : "Nie sú nastavené žiadne zariadenia.",
    "The following devices are configured for your account:" : "Pre váš účet máte nastavené nasledujúce zariadenia:",
    "Your browser does not support WebAuthn." : "Váš prehliadač nepodporuje WebAuthn.",
    "Your apps" : "Vaše aplikácie",
    "{license}-licensed" : "{license}-licencovaný",
    "Changelog" : "Zoznam zmien",
    "by {author}\n{license}" : "od {author}\n{license}",
    "Enter group name" : "Zadajte názov skupiny",
    "Add group" : "Pridať skupinu",
    "Active users" : "Aktívni užívatelia",
    "Admins" : "Administrátori",
    "Disabled users" : "Zablokovaní používatelia",
    "Default quota:" : "Predvolená kvóta:",
    "Select default quota" : "Vybrať predvolenú kvótu",
    "Show Languages" : "Zobraziť jazyky",
    "Show last login" : "Zobraziť posledné prihlásenie",
    "Show user backend" : "Zobraziť backend používateľa",
    "Show storage path" : "Zobraziť popis umiestnenia úložiska",
    "Send email to new user" : "Odoslať email novému používateľovi",
    "Not saved" : "Neuložené",
    "Sending…" : "Odosielam...",
    "Email sent" : "Email odoslaný",
    "Location" : "Umiestnenie",
    "Profile picture" : "Avatar",
    "About" : "O aplikácii",
    "Full name" : "Meno a priezvisko",
    "Additional email" : "Ďalšie e-maily",
    "Headline" : "Titulok",
    "Organisation" : "Organizácia",
    "Phone number" : "Telefónne číslo",
    "Role" : "Rola",
    "Twitter" : "Twitter",
    "Website" : "Webstránka",
    "Profile visibility" : "Viditeľnosť profilu",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Nie je k dispozícii, pretože táto vlastnosť je potrebná pre základné funkcie vrátane zdieľania súborov a pozvánok do kalendára",
    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Nie je k dispozícii, pretože federácia bola pre váš účet zakázaná. Ak máte nejaké otázky, kontaktujte správcu systému",
    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Nie je k dispozícii, pretože publikovanie špecifických údajov užívateľa na vyhľadávacom serveri nie je povolené. Ak máte nejaké otázky, kontaktujte správcu systému",
    "Active apps" : "Aktívne aplikácie",
    "Disabled apps" : "Zakázané aplikácie",
    "Updates" : "Aktualizácie",
    "App bundles" : "Aplikačné balíky",
    "Featured apps" : "Odporúčané aplikácie",
    "Show to everyone" : "Viditeľné pre všetkých",
    "Show to logged in users only" : "Viditeľné iba pre prihlásených užívateľov",
    "Hide" : "Skyť",
    "Download and enable" : "Stiahnuť a povoliť",
    "Enable untested app" : "Zapnúť netestovanú aplikáciu",
    "The app will be downloaded from the App Store" : "Aplikácia bude stiahnutá z obchodu",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Táto aplikácia nie je označená ako kompatibilná s vašou verziou Nextcloud. Ak budete pokračovať, aplikáciu budete môcť stále nainštalovať. Aplikácia nemusí fungovať podľa očakávania.",
    "Never" : "Nikdy",
    "An error occurred during the request. Unable to proceed." : "Počas vykonania požiadavky nastala chyba.  Nie je možné pokračovať.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikácia bola povolená, ale vyžaduje sa aktualizácia. Presmerovanie na stránku aktualizácie o 5 sekúnd.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Chyba: aplikáciu nie je možné povoliť, lebo naruší stabilitu servera",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Príliš mnoho požiadaviek z vašej siete. Skúste to znovu neskôr alebo kontaktujte svojho administrátora ak je toto chyba.",
    "Documentation" : "Dokumentácia",
    "Forum" : "Fórum",
    "Login" : "Prihlásenie",
    "SSL/TLS" : "SSL/TLS",
    "Open documentation" : "Otvoriť dokumentáciu",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Je dôležité nastaviť aby server vedel odosielať emaily, napríklad pre nastavenie hesla a notifikácie.",
    "Send mode" : "Mód odosielania",
    "Encryption" : "Šifrovanie",
    "Sendmail mode" : "Režim sendmail",
    "From address" : "Z adresy",
    "Server address" : "Adresa servera",
    "Port" : "Port",
    "Authentication method" : "Autentifikačná metóda",
    "Authentication required" : "Vyžaduje sa overenie",
    "Credentials" : "Prihlasovanie údaje",
    "SMTP Username" : "SMTP používateľské meno",
    "SMTP Password" : "SMTP heslo",
    "Save" : "Uložiť",
    "Test and verify email settings" : "Otestovať a overiť nastavenia e-mailu",
    "Send email" : "Odoslať email",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Z hľadiska bezpečnosti a výkonu Vašej inštalácie je dôležité, že všetko je správne nastavené. Robíme automatickú kontrolu, ktorá Vám s tým pomáha. Pre ďalšie informácie nahliadnite do priloženej dokumentácie.",
    "All checks passed." : "Všetky kontroly prešli úspešne.",
    "There are some errors regarding your setup." : "Vo Vašom nastavení sú nejaké chyby.",
    "There are some warnings regarding your setup." : "Vo Vašom nastavení sú nejaké varovania.",
    "Checking for system and security issues." : "Prebieha kontrola systémových a bezpečnostných problémov.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Prosím skontrolujte <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">inštalačnú dokumentáciu</a> a skontrolujte existenciu chýb a upozornení v <a href=\"%2$s\">logu</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Skontrolujte bezpečnosť Vášho Nextcloud pomocou <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">nášho bezpečnostného scanu</a>.",
    "Version" : "Verzia",
    "You need to enable the File sharing App." : "Musíte povoliť Aplikáciu pre zdieľanie súborov.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Ako administrátor môžete nastaviť správanie sprístupňovania. Pre viac informácií pozrite dokumentáciu.",
    "Allow apps to use the Share API" : "Povoliť aplikáciám používať API pre sprístupňovanie",
    "Set default expiration date for shares" : "Nastavte predvolený dátum expirácie pre zdieľania",
    "Expire after" : "Platnosť do",
    "day(s)" : "deň (dni)",
    "Enforce expiration date" : "Vynútiť dátum expirácie",
    "Set default expiration date for shares to other servers" : "Nastaviť predvolený dátum vypršania platnosti zdieľaní na iné servery",
    "Allow users to share via link and emails" : "Povoliť používateľom zdieľanie obsahu pomocou odkazov",
    "Allow public uploads" : "Povoliť verejné nahrávanie súborov",
    "Always ask for a password" : "Vždy vyžadovať heslo",
    "Enforce password protection" : "Vynútiť ochranu heslom",
    "Exclude groups from password requirements:" : "Vylúčiť skupiny z požiadaviek na heslo:",
    "Set default expiration date" : "Nastaviť predvolený dátum expirácie",
    "Exclude groups from creating link shares:" : "Nepovoliť skupinám vytvárať odkazy k zdieľaniu:",
    "Allow resharing" : "Povoliť sprístupňovanie ďalej",
    "Allow sharing with groups" : "Povoliť sprístupnenie so skupinami",
    "Restrict users to only share with users in their groups" : "Povoliť používateľom sprístupňovanie obsahu len v rámci ich skupiny",
    "Exclude groups from sharing" : "Nesprístupniť obsah skupinám",
    "These groups will still be able to receive shares, but not to initiate them." : "Tieto skupiny nebudú mocť sprístupňovať obsah, môžu však stále čítať sprístupnené súbory.",
    "Allow username autocompletion in share dialog" : "Povoliť automatické dopĺňanie používateľského mena v dialógovom okne zdieľania",
    "Allow username autocompletion to users within the same groups" : "Povoliť automatické dopĺňanie mien užívateľom v rovnakých skupinách",
    "Allow username autocompletion to users based on phone number integration" : "Povoliť automatické dopĺňanie mien užívateľom založené na integrácii s telefónnym číslom",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Ak je povolené automatické dopĺňanie „pre rovnakú skupinu“ a „integrácia telefónneho čísla“, na zobrazenie používateľa stačí zhoda v ktorejkoľvek z nich.",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Pri zadávaní celého mena alebo e-mailovej adresy povoliť automatické dopĺňanie (ignoruje sa chýbajúca zhoda v telefónnom zozname a príslušnosť k rovnakej skupine)",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Zobraziť text upozornenia na stránke pre nahrávanie verejného odkazu (zobraziť len ak je zoznam súborov skrytý)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Ak nebude zoznam súborov skrytý, tento text sa zobrazí na stránke pre nahrávanie verejného odkazu.",
    "Default share permissions" : "Prednastavené povolenia pre zdieľanie",
    "Reasons to use Nextcloud in your organization" : "Dôvody použitia NextCloudu vo vašej organizácii",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Vyvíjané {communityopen}komunitou Nextcloud{linkclose}, {githubopen}zdrojové kódy{linkclose} sú licencované pod licenciou {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Sleduj nás na Facebook-u",
    "Follow us on Twitter" : "Sleduj nás na Twitter-i",
    "Follow us on Mastodon" : "Sledujte nás na Mastodon",
    "Check out our blog" : "Pozri si náš blog",
    "Subscribe to our newsletter" : "Prihlás sa na odber noviniek emailom",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Toto komunitné vydanie Nextcloud nie je podporované a okamžité upozornenia nie sú k dispozícii.",
    "Use a second factor besides your password to increase security for your account." : "Pre zlepšenie zabezpečenia vášho účtu použite okrem hesla aj druhý faktor.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Ak na pripojenie k NextCloudu používate aplikácie tretích strán, pred povolením dvojstupňového overovania totožnosti, nezabudnite pre každú z nich vytvoriť a nastaviť heslo aplikácie.",
    "An error occurred while changing your language. Please reload the page and try again." : "Počas zmeny jazyka sa vyskytla chyba. Prosím obnovte stránku a skúste znova.",
    "An error occurred while changing your locale. Please reload the page and try again." : "Počas zmeny jazyka sa vyskytla chyba. Prosím obnovte stránku a skúste znova.",
    "Select a profile picture" : "Vybrať avatara",
    "Week starts on {fdow}" : "Den začína v {fdow}",
    "You created app password \"{token}\"" : "Vytvorili ste heslo pre aplikáciu \"{token}\"",
    "An administrator created app password \"{token}\"" : "Administrátor vytvoril heslo pre aplikáciu \"{token}\"",
    "Couldn't remove app." : "Nemožno odstrániť aplikáciu.",
    "Couldn't update app." : "Nemožno aktualizovať aplikáciu.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "Backend nepodporuje zmenu hesla, ale šifrovací kľúč používateľa bol zmenený.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Nepodarilo sa zistiť, či je verzia TLS na cURL zastaraná alebo nie, pretože sa vyskytla chyba počas požiadavky HTTPS na https://nextcloud.com. Ďalšie podrobnosti nájdete v log súbore nextcloud.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Maximálny počet kľúčov OPcache je takmer prekročený. Aby ste sa uistili, že všetky skripty môžu byť uložené vo vyrovnávacej pamäti, odporúča sa použiť <code>opcache.max_accelerated_files</code> na vašu konfiguráciu PHP s hodnotou vyššou ako <code>%s</code>.",
    "Admin privileges" : "Oprávnenie správcu",
    "Unable to update biography" : "Nie je možné aktualizovať životopis",
    "Unable to update full name" : "Nie je možné aktualizovať vaše celé meno",
    "No full name set" : "Nie je nastavené celé meno",
    "Unable to update headline" : "Nie je možné aktualizovať titulok",
    "Unable to update organisation" : "Nie je možné aktualizovať vašu organizáciu",
    "Unable to update role" : "Nie je možné aktualizovať rolu",
    "Change scope level of {accountProperty}" : "Zmeniť úroveň rozsahu pre {accountProperty}",
    "Unable to update federation scope of the primary {accountProperty}" : "Nie je možné aktualizovať rozsah federácie primárneho {accountProperty}",
    "Unable to update federation scope of additional {accountProperty}" : "Nie je možné aktualizovať rozsah federácie dodatočného {accountProperty}",
    "Migration in progress. Please wait until the migration is finished" : "Prebieha migrácia. Počkajte prosím, kým sa skončí",
    "Migration started …" : "Migrácia spustená ...",
    "Address" : "Adresa",
    "Avatar" : "Avatar",
    "An error occured during the request. Unable to proceed." : "Počas vykonania požiadavky nastala chyba.  Nie je možné pokračovať.",
    "Plain" : "Neformátovaný",
    "NT LAN Manager" : "NT LAN Manager",
    "STARTTLS" : "STARTTLS",
    "Please read carefully before activating server-side encryption: " : "Prečítajte prosím pozorne pred použitím šifrovania na serveri:",
    "Enable encryption" : "Povoliť šifrovanie",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Musíte migrovať vaše šifrovacie kľúče zo starého šifrovania (ownCloud <= 8,0) na nové. Prosím zapnite \"Predvolený šifrovací modul\" a spustite „occ encryption:migrate“",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Musíte preniesť svoje šifrovacie kľúče zo starej verzie šifrovania (ownCloud <= 8.0) na novú.",
    "Start migration" : "Začať migráciu",
    "Last job execution ran %s. Something seems wrong." : "Úloha naposledy prebehla %s. Zdá sa, že niečo nie je v poriadku.",
    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Niektoré úlohy sa nevykonali už od %s. Zvážte zvýšenie frekvencie vykonávania.",
    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Niektoré úlohy neboli vykonané už od %s. Zvážte prechod na plánovač systému - cron.",
    "Last job ran %s." : "Úloha naposledy prebehla %s.",
    "Background job didn’t run yet!" : "Úloha na pozadí ešte nebežala!",
    "For the server to work properly, it's important to configure background jobs correctly. \"Cron\" is the recommended setting. Please see the documentation for more information." : "Pre optimálny výkon je dôležité nakonfigurovať úlohy na pozadí správne. Odporúča sa 'Cron'. Viac informácií je možné nájsť v dokumentácii.",
    "Pick background job setting" : "Vybrať nastavenie úlohy na pozadí",
    "Recommended" : "Odporúčané",
    "The cron.php needs to be executed by the system user \"%s\"." : "Je potrebné, aby cron.php bol spustený systémovým používateľom \"%s\".",
    "Change privacy level of profile picture" : "Zmeniť úroveň súkromia pre profilový obrázok",
    "Upload new" : "Nahrať nový",
    "Select from Files" : "Vybrať zo súborov",
    "Remove image" : "Zmazať obrázok",
    "png or jpg, max. 20 MB" : "png alebo jpg, max. 20 MB",
    "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "Upozorňujeme, že aktualizácia avatara môže trvať až 24 hodín.",
    "Choose as profile picture" : "Použiť ako obrázok avatara",
    "You are using <strong>%s</strong>" : "Využívate <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Využívate <strong>%1$s</strong> z <strong>%2$s</strong> (<strong>%3$s%%</strong>)",
    "Change privacy level of phone number" : "Zmeniť úroveň súkromia pre telefónne číslo",
    "Change privacy level of address" : "Zmeniť úroveň súkromia pre adresu",
    "Your postal address" : "Vaša poštová adresa",
    "Change privacy level of website" : "Zmeniť úroveň súkromia pre webstránku",
    "It can take up to 24 hours before the account is displayed as verified." : "Môže trvať až 24 hodín než sa účet zobrazí ako overený.",
    "Link https://…" : "Linka https://…",
    "Change privacy level of Twitter profile" : "Zmeniť úroveň súkromia pre Twitterový profil",
    "Twitter handle @…" : "Prezývka na Twitteri @…",
    "Choose profile picture from files" : "Vybrať profilový obrázok zo súborov"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
